/* @group colorset */

.colorChooser {
  border: 1px solid #ddd;
  padding: 0.5em;
  margin: 0.5em 0;
}
.colorSet {
  float: left;
}
.colorSet div.labelColor {
  height: 2em;
  width: 2em;
  display: block;
  border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  margin: 1px;
  cursor: pointer;
}
.colorSet .selected div.labelColor {
  border: 1px solid #000;
  margin: 0;
}

/* @end */

/* @group labelJarPortlet */

.labelListing .labelColor {
  border: 1px solid;
  padding: 0.25em;
  margin: 0 0.25em;
  margin-bottom: 0.25em;
  border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  position: relative;
  overflow: hidden;
}
.editLabelLink {
  text-indent: -4000em;
  display: block;
  width: 20px;
  height: 20px;
  position: absolute;
  top: 0;
  right: 0;
  background: url(++resource++ftw.labels/settings.png) no-repeat center center;
  opacity: 0.7;
}
.editLabelLink:hover {
  opacity: 1;
}
.labelListing .labelItem .labelColor:hover,
.labelListing .labelItem.selected  .labelColor {
  cursor: pointer;
  border-color: #000;
  box-shadow: 0 0 0.1em #aaa;
  -webkit-box-shadow: 0 0 0.1em #aaa;
  -moz-box-shadow: 0 0 0.1em #aaa;
}
.editLabelForm #label-title {
  margin-left: 1em;
}

/* @end */

/* @group labeling viewlet */

#content #labeling-viewlet ul li #toggle-label-form {
  text-indent: -4000em;
  background: url(++resource++ftw.labels/edit_labels.png) no-repeat center center;
  width: 24px;
  height: 18px;
  padding: 0 0.25em;
  opacity: 0.5;
  border: none;
}
#content #labeling-viewlet ul li #toggle-label-form:hover {
  opacity: 1;
}
#labeling-viewlet form {
  display: none;
  margin-bottom: 0.5em;
}
#content #labeling-viewlet ul {
  list-style: none;
  margin-left: 0;
}
#content #labeling-viewlet > ul > li {
  margin: 0;
}
#content #labeling-viewlet > ul > li > .labelItem,
#content #toggle-label-form {
  display: block;
  float: left;
  padding: 0.25em;
  font-size: 11px;
  line-height: 1em;
  white-space: nowrap;
  margin: 0 0.25em 0.25em 0;
}
#content #labeling-viewlet ul li .labelItem {
  border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
}

/* @end */

/* @group label colors */


.labelColor.labelItem {
  border: 1px solid #eee;
  color: #000;
}
.labelJarPortlet .labelListing .labelColor {
  background: transparent;
  border: none;
  color: #000;
}
.labelJarPortlet .labelListing .labelColor:before {
  content: '•';
  border: 1px solid #aaa;
  display: block;
  height: 1em;
  width: 1em;
  float: left;
  margin-right: 0.25em;
  border-radius: 1em;
  -webkit-border-radius: 1em;
  -moz-border-radius: 1em;
}
.labelJarPortlet .labelListing .selected .labelColor:before {
  border-color: transparent;
}
.labelJarPortlet .labelColor a.editLabelLink {
  display: none;
}
.labelJarPortlet .labelColor:hover a.editLabelLink {
  display: block;
}


/* generated with scss */


/*

$lighter: 43%;
$border-darker: 10%;

@mixin label($name, $color) {
  .labelColor.labelcolor-#{$name} {
    background: $color;
    border-color: darken($color, $border-darker);
    @if ($name!=yellow) {
    color: #FFF;
    }
  }
  @if ($name!=yellow) {
    @include filter_label($name, $color, #fff);
  }
  @else {
    @include filter_label($name, $color, #000);
  }
  $light: lighten($color, $lighter);
  .labelColor.labelcolor-#{$name}-light {
    background: $light;
    border-color: darken($light, $border-darker);
  }
  @include filter_label($name+'-light', $light, #000);
}

@mixin filter_label($name, $color, $font-color) {
  .labelJarPortlet .labelListing .labelColor.labelcolor-#{$name} {
    &:before {
      color: $color;
      background-color: $color;
    }
  }
  .labelJarPortlet .labelListing .selected .labelColor.labelcolor-#{$name} {
    background: $color;
    color: $font-color;
  }
}


@include label(red,#e11d21);
@include label(orange,#eb6420);
@include label(yellow,#fbca04);
@include label(green,#009800);
@include label(cadetblue,#006b75);
@include label(cornflowerblue,#207de5);
@include label(blue,#0052cc);
@include label(purple,#5319e7);



 */





.labelColor.labelcolor-red {
  background: #e11d21;
  border-color: #b4171a;
  color: #FFF;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-red:before {
  color: #e11d21;
  background-color: #e11d21;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-red {
  background: #e11d21;
  color: white;
}

.labelColor.labelcolor-red-light {
  background: #fbdedf;
  border-color: #f5b1b3;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-red-light:before {
  color: #fbdedf;
  background-color: #fbdedf;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-red-light {
  background: #fbdedf;
  color: black;
}

.labelColor.labelcolor-orange {
  background: #eb6420;
  border-color: #c64e12;
  color: #FFF;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-orange:before {
  color: #eb6420;
  background-color: #eb6420;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-orange {
  background: #eb6420;
  color: white;
}

.labelColor.labelcolor-orange-light {
  background: #fdf0e9;
  border-color: #f9cfba;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-orange-light:before {
  color: #fdf0e9;
  background-color: #fdf0e9;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-orange-light {
  background: #fdf0e9;
  color: black;
}

.labelColor.labelcolor-yellow {
  background: #fbca04;
  border-color: #c9a203;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-yellow:before {
  color: #fbca04;
  background-color: #fbca04;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-yellow {
  background: #fbca04;
  color: black;
}

.labelColor.labelcolor-yellow-light {
  background: #fef8dc;
  border-color: #feedaa;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-yellow-light:before {
  color: #fef8dc;
  background-color: #fef8dc;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-yellow-light {
  background: #fef8dc;
  color: black;
}

.labelColor.labelcolor-green {
  background: #009800;
  border-color: #006500;
  color: #FFF;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-green:before {
  color: #009800;
  background-color: #009800;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-green {
  background: #009800;
  color: white;
}

.labelColor.labelcolor-green-light {
  background: #74ff74;
  border-color: #41ff41;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-green-light:before {
  color: #74ff74;
  background-color: #74ff74;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-green-light {
  background: #74ff74;
  color: black;
}

.labelColor.labelcolor-cadetblue {
  background: #006b75;
  border-color: #003c42;
  color: #FFF;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-cadetblue:before {
  color: #006b75;
  background-color: #006b75;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-cadetblue {
  background: #006b75;
  color: white;
}

.labelColor.labelcolor-cadetblue-light {
  background: #51f0ff;
  border-color: #1eecff;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-cadetblue-light:before {
  color: #51f0ff;
  background-color: #51f0ff;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-cadetblue-light {
  background: #51f0ff;
  color: black;
}

.labelColor.labelcolor-cornflowerblue {
  background: #207de5;
  border-color: #1664bc;
  color: #FFF;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-cornflowerblue:before {
  color: #207de5;
  background-color: #207de5;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-cornflowerblue {
  background: #207de5;
  color: white;
}

.labelColor.labelcolor-cornflowerblue-light {
  background: #e4effc;
  border-color: #b7d5f7;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-cornflowerblue-light:before {
  color: #e4effc;
  background-color: #e4effc;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-cornflowerblue-light {
  background: #e4effc;
  color: black;
}

.labelColor.labelcolor-blue {
  background: #0052cc;
  border-color: #003d99;
  color: #FFF;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-blue:before {
  color: #0052cc;
  background-color: #0052cc;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-blue {
  background: #0052cc;
  color: white;
}

.labelColor.labelcolor-blue-light {
  background: #a8cbff;
  border-color: #75adff;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-blue-light:before {
  color: #a8cbff;
  background-color: #a8cbff;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-blue-light {
  background: #a8cbff;
  color: black;
}

.labelColor.labelcolor-purple {
  background: #5319e7;
  border-color: #4213ba;
  color: #FFF;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-purple:before {
  color: #5319e7;
  background-color: #5319e7;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-purple {
  background: #5319e7;
  color: white;
}

.labelColor.labelcolor-purple-light {
  background: #e8e0fc;
  border-color: #c5b1f7;
}

.labelJarPortlet .labelListing .labelColor.labelcolor-purple-light:before {
  color: #e8e0fc;
  background-color: #e8e0fc;
}

.labelJarPortlet .labelListing .selected .labelColor.labelcolor-purple-light {
  background: #e8e0fc;
  color: black;
}


/* @end */

/* @group select2 adjustments */

#s2id_activate_labels {
  width: 100%;
  margin-bottom: 0.25em;
}
#content #s2id_activate_labels ul {
  margin-bottom: 0;
}
#content #s2id_activate_labels li {
  line-height: 1em;
  font-size: 11px;
}
.select2-container-multi .select2-search-choice-close {
  top: 2px;
}

/* @end */